clixx.arguments
===============

.. currentmodule:: clixx.arguments

Classes
-------

.. autoclass:: Argument
    :members:
    :show-inheritance:

.. autoclass:: Option
    :members:
    :show-inheritance:

.. autoclass:: FlagOption
    :members:
    :show-inheritance:

.. autoclass:: AppendOption
    :members:
    :show-inheritance:

.. autoclass:: CountOption
    :members:
    :show-inheritance:

.. autoclass:: SignalOption
    :members:
    :show-inheritance:

.. autoclass:: HelpOption
    :members:
    :show-inheritance:

.. autoclass:: VersionOption
    :members:
    :show-inheritance:
